==> nip2_7.10.20.orig.tar.gz: nip2-7.10.20/src/iarrowview.h <==
/* a iarrow view in a workspace
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#define TYPE_IARROWVIEW (iarrowview_get_type())
#define IARROWVIEW( obj ) \
	(GTK_CHECK_CAST( (obj), TYPE_IARROWVIEW, iArrowview ))
#define IARROWVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_IARROWVIEW, iArrowviewClass ))
#define IS_IARROWVIEW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_IARROWVIEW ))
#define IS_IARROWVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_IARROWVIEW ))

typedef struct _iArrowview {
	Graphicview parent_object;

	GtkWidget *label;
} iArrowview;

typedef struct _iArrowviewClass {
	GraphicviewClass parent_class;

	/* My methods.
	 */
} iArrowviewClass;

GtkType iarrowview_get_type( void );
View *iarrowview_new( void );

==> nip_7.8.14.orig.tar.gz: nip-7.8.14/src/iarrowview.h <==
/* a iarrow view in a workspace
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

 */

#define TYPE_IARROWVIEW (iarrowview_get_type())
#define IARROWVIEW( obj ) \
	(GTK_CHECK_CAST( (obj), TYPE_IARROWVIEW, Iarrowview ))
#define IARROWVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_IARROWVIEW, IarrowviewClass ))
#define IS_IARROWVIEW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_IARROWVIEW ))
#define IS_IARROWVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_IARROWVIEW ))

typedef struct _Iarrowview {
	View view;

	GtkWidget *label;
} Iarrowview;

typedef struct _IarrowviewClass {
	ViewClass parent_class;

	/* My methods.
	 */
} IarrowviewClass;

GtkType iarrowview_get_type( void );
View *iarrowview_new( void );
